/****************************************************************************/
/*! \file		chsim_param.c
	\brief		Channel simulater parameters
	\author		Iliya Voronov, http://powerdsp.narod.ru
	\version	0.0
     
	Define channel parameters, used by channel simulator. 
*/
/*****************************************************************************/

#include <string.h>
#include "chsim_param.h"


/*****************************************************************************
Channel linear distortion 
*****************************************************************************/

//! Channel linear distortion FIR coefficients
/*!	There is 4 channel distortion types with following
	linear distortions in dB vs Hz:
	type	600		1000	1600	2500	2800	3000	file
	flat	0.0		0.0		0.0		0.0		0.0		0.0		chanFlat
	good	1.5		0.5		0.0		0.5		1.5		3.0		chanGood
	midd	3.0		1.0		0.0		1.0		3.0		6.0		chanMidd
	poor	6.0		2.0		0.0		2.0		6.0	   12.0		chanPoor
	Linear distortions are modeled by multiband FIR filters,
	designed in QED2000, spc/flt files in subdir filt
	Sample rate 8000Hz, tap number 32
*/
const int16 CHSIM_aChanCoef[ CHSIM_CHT_NUM ][ CHSIM_CHAN_FIR_SZ ] = {
	{ // flat
		  0,	  6,   -101,	 46,   -332,	-79,   -446,   -767,
	   -170,  -2006,	 87,  -2709,  -1105,   -709,  -6873,  18095,
	  18095,  -6873,   -709,  -1105,  -2709,	 87,  -2006,   -170,
	   -767,   -446,	-79,   -332,	 46,   -101,	  6,	  0
	},
	{ // good
		171,      4,    233,    168,     13,    368,   -424,    127,
	   -718,  -1306,   -245,  -3217,   -590,  -3703,  -6452,  15349,
	  15349,  -6452,  -3703,   -590,  -3217,   -245,  -1306,   -718,
		127,   -424,    368,     13,    168,    233,      4,    171
	},
	{ // midd
		131,    -16,    142,    133,     32,    240,   -190,    137,
	   -652,   -858,   -362,  -2520,   -417,  -4397,  -5922,  14310,
	  14310,  -5922,  -4397,   -417,  -2520,   -362,   -858,   -652,
		137,   -190,    240,     32,    133,    142,    -16,    131
	},
	{ // poor
		 86,    -66,     15,    101,     40,     99,    102,    148,
	   -544,   -370,   -385,  -1369,   -230,  -5266,  -5178,  12628,
	  12628,  -5178,  -5266,   -230,  -1369,   -385,   -370,   -544,
		148,    102,     99,     40,    101,     15,    -66,     86
	}
};






/*****************************************************************************
Echo
*****************************************************************************/

//! Near echo FIR coefficients
/*! It is multiband FIR filter, designed in QED2000,
	files filt/echo.spc and filt/echo.flt.
	Sample rate 8000Hz, full tap number 48.
	Bands:	 300- 900, 1.0 +-0.5
			1000-1200, 0.3 +-0.5
			5500-3300, 1.0 +-0.5
	Coefficients 11 - 42 are used only.
*/
const int16 CHSIM_aNearEchoCoef[ CHSIM_ECHO_FIR_SZ ] = {
    521,   -200,   2377,    -79,    933,  -2976,   -149,  -2405,
   3590,   -800,   5590,  -7440,  18799,  18799,  -7440,   5590,
   -800,   3590,  -2405,   -149,  -2976,    933,    -79,   2377,
   -200,    521,  -1630,     59,   -756,    953,   -277,    663,
};

//! Far echo FIR coefficients
/*! It is multiband FIR filter, designed in QED2000,
	files filt/echo.spc and filt/echo.flt.
	Sample rate 8000Hz, full tap number 48.
	Bands:	 300- 900, 1.0 +-0.5
			1000-1200, 0.3 +-0.5
			5500-3300, 1.0 +-0.5
	Coefficients 11 - 42 are used only.
*/
const int16 CHSIM_aFarEchoCoef[ CHSIM_ECHO_FIR_SZ ] = {
    521,   -200,   2377,    -79,    933,  -2976,   -149,  -2405,
   3590,   -800,   5590,  -7440,  18799,  18799,  -7440,   5590,
   -800,   3590,  -2405,   -149,  -2976,    933,    -79,   2377,
   -200,    521,  -1630,     59,   -756,    953,   -277,    663,
};





