/****************************************************************************/
/*! \file		chsim_param.h
	\brief		Channel simulater parameters
	\author		Iliya Voronov, http://powerdsp.narod.ru
	\version	0.0
     
	Define channel parameters, used by channel simulator. 
*/
/*****************************************************************************/

#ifndef _CHSIM_PARAM_H_
#define _CHSIM_PARAM_H_


#include "chsim.h"


/*****************************************************************************
Channel linear distortion 
*****************************************************************************/

//! Channel linear distortion FIR coefficients
/*!	There is 4 channel distortion types with following
	linear distortions in dB vs Hz:
	type	600		1000	1600	2500	2800	3000	file
	flat	0.0		0.0		0.0		0.0		0.0		0.0		chanFlat
	good	1.5		0.5		0.0		0.5		1.5		3.0		chanGood
	midd	3.0		1.0		0.0		1.0		3.0		6.0		chanMidd
	poor	6.0		2.0		0.0		2.0		6.0	   12.0		chanPoor
	Linear distortions are modeled by multiband FIR filters,
	designed in QED2000, spc/flt files in subdir filt
	Sample rate 8000Hz, tap number 32
*/
extern const int16 CHSIM_aChanCoef[ CHSIM_CHT_NUM ][ CHSIM_CHAN_FIR_SZ ];



/*****************************************************************************
Echo
*****************************************************************************/

//! Near echo FIR coefficients
/*! It is multiband FIR filter, designed in QED2000,
	files filt/echo.spc and filt/echo.flt.
	Sample rate 8000Hz, full tap number 48.
	Bands:	 300- 600, 1.0 +-0.5
			1000-1200, 0.01+-0.1
			2500-3300, 1.0 +-0.5
	Coefficients 11 - 42 are used only.
*/
extern const int16 CHSIM_aNearEchoCoef[ CHSIM_ECHO_FIR_SZ ];


//! Far echo FIR coefficients
/*! It is multiband FIR filter, designed in QED2000,
	files filt/echo.spc and filt/echo.flt.
	Sample rate 8000Hz, full tap number 48.
	Bands:	 300- 600, 1.0 +-0.5
			1000-1200, 0.01+-0.1
			2500-3300, 1.0 +-0.5
	Coefficients 11 - 42 are used only.
*/
extern const int16 CHSIM_aFarEchoCoef[ CHSIM_ECHO_FIR_SZ ];



#endif //#ifndef _CHSIM_PARAM_H_
