/****************************************************************************/
/*! \file		comtypes.h
	\brief		Common types
	\author		Iliya Voronov, http://powerdsp.narod.ru
	\version	1.0
     
  Common typese and handy functions.
*/
/*****************************************************************************/

#ifndef _COMTYPES_H_
#define _COMTYPES_H_




/*****************************************************************************
Identify compiler
*****************************************************************************/

#undef COMPILER_MSVC
#undef COMPILER_GNUC
#undef COMPILER_C64
#undef COMPILER_C55
#undef COMPILER_C28

#if (defined _MSC_VER) || (defined WIN32)
	#define COMPILER_MSVC /* Microsoft Visual C++ */
#elif defined __GNUC__
	#define COMPILER_GNUC	/* Linux GNU C/C++ */
#elif defined _TMS320C6400
	#define COMPILER_C64
#elif defined __TMS320C55X__
	#define COMPILER_C55
#elif defined __TMS320C28XX__	
	#define COMPILER_C28
#else
	#error Undefined compiler
#endif /* compiler still unknown */

#ifdef _DEBUG
  #include <assert.h>
  #include <stdio.h>
#endif

/*****************************************************************************
Common integer types
*****************************************************************************/

#ifdef COMPILER_C64
	typedef long long int		int64;
	typedef unsigned long long 	uint64;
	typedef long int   			int40;
	typedef unsigned long int	uint40;
	typedef int					int32;
	typedef unsigned int		uint32;
	typedef short int			int16;
	typedef unsigned short int	uint16;
	typedef char				int8;
	typedef unsigned char		uint8;
#else //#ifdef COMPILER_C64
	typedef long long int		int64;
	typedef unsigned long long 	uint64;
	typedef long long int		int40;
	typedef unsigned long long	uint40;
	typedef long int			int32;
	typedef unsigned long int	uint32;
	typedef short int 			int16;
	typedef unsigned short int 	uint16;
	typedef char				int8;
	typedef unsigned char		uint8;
#endif //#ifdef COMPILER_C64

#define MIN_INT16 (int16)0x8000
#define MAX_INT16 (int16)0x7fff
#define MIN_INT32 (int32)0x80000000
#define MAX_INT32 (int32)0x7fffffff
#define MIN_INT40 (int40)0xffffff8000000000
#define MAX_INT40 (int40)0x0000007fffffffff
#define MAX_UINT16 (uint16)0xffff
#define MAX_UINT32 (uint32)0xffffffff

#ifndef __cplusplus
typedef int bool;
#ifndef false
#define false 0
#endif
#ifndef true
#define true 1
#endif
#endif

typedef struct comp16 {
  int16 re;
  int16 im;
} comp16;

typedef struct comp32 {
  int32 re;
  int32 im;
} comp32;


/*****************************************************************************
Common fractional types
*****************************************************************************/

typedef  int16	fract0q15;		// [-1., 1.)
typedef  int16	fract2q13;		// [-4., 4.)
typedef  int16	fract5q10;		// [-32.,32.)
typedef  int16	fract7q8;		// [-128.,128.)

typedef  int16	fractRad;		// [-pi, pi)

typedef  uint16	ufract0q16;		// [0., 1.)

typedef  int32  fract0q31;		// [-1., 1.)
typedef  int32  fract7q23;		// [-128.,128.)

typedef	 uint32 ufract0q32;		// [0., 1.)

/*****************************************************************************
                        Language-dependent definitions
*****************************************************************************/

#undef _extern_c_
#ifdef __cplusplus
	#define _extern_c_ extern "C"
#else
	#define _extern_c_ 
#endif

#undef _inline_
#if (defined COMPILER_MSVC)
	#define _inline_ __inline
#else
	#define _inline_ static inline
#endif

#undef ASSERT
#ifdef COMPILER_MSVC
	#ifdef _DEBUG
		#define ASSERT(x)  assert(x)
    #else
		#define ASSERT(_ignore)  ((void)0)
    #endif
#else
	#ifdef _DEBUG
		#define ASSERT(x)  assert(x)
    #else
//		#define ASSERT(x)  if(!(x)){sysStopShowErr();}
		#define ASSERT(_ignore)  ((void)0)
    #endif
#endif


#undef _debugPrintf_
#ifdef _DEBUG
  #define _debugPrintf_(x)  printf(x)
#else
  #define _debugPrintf_(_ignore)  ((void)0)
#endif


#ifdef COMPILER_MSVC
#define snprintf _snprintf
#endif


/*****************************************************************************
                        Usefull macros
*****************************************************************************/

#ifndef _TMS320C6X
// absent on non 6XXXX platform
#define restrict
#endif

//! should be defined somewhere around main
extern void printArr(  const int16 * pData, uint16 len );
extern void printLarr( const int32 * pData, uint16 len );
__inline void printVal(  int16 a ) { printArr(  &a, 1 ); }
__inline void printLval( int32 a ) { printLarr( &a, 1 ); }




#endif //#ifndef _COMTYPES_H_



