/****************************************************************************/
/*! \file		parse.h
	\brief		Parser for configuration file
	\author		Iliya Voronov, http://powerdsp.narod.ru
	\version	1.0
  
	It is parser for configuration file. Test bench commands are parsed here,
	if command is not valide test bench command, it is transfered to 
	channel simulator for parsing. 
*/
/*****************************************************************************/

#ifndef _PARSE_CFG_H_
#define _PARSE_CFG_H_

#include <stdio.h>
#include "comtypes.h"
#include "chsim.h"



/******************************************************************************
Internal definitions
******************************************************************************/

//! Sample file number
#define PARSE_SF_NUM 2

//! Bits file types
typedef enum enPARSE_bitsFile {
	PARSE_BF_TR0,	// Tr0 bits
	PARSE_BF_TR1,	// Tr1 bits
	PARSE_BF_RC0,	// Rc0 bits
	PARSE_BF_RC1,	// Rc1 bits
	PARSE_BF_NUM	// bits file number
} ePARSE_bitsFile;



//! Parsed configuration structure for current session for file IO and MatLab vis objects
typedef struct tagPARSE_cfg {
	bool		aiSaveSamp[PARSE_SF_NUM];	//!< is Save modem 0/1 TrRc samples to stereo file
	bool		aiSaveBits[PARSE_BF_NUM];	//!< is Save modem Tr0/Tr1/Rc0/Rc1 bits to file
	uint32		logPerMs;	//!< Set logging period in ms
	bool		iLenInBits;	//!< is session length in bits, otherwise in ms
	uint32		sesLen;		//!< session length in ms or in bits
} tPARSE_cfg;



/******************************************************************************
Object instance and interface parameters
******************************************************************************/

// File parser object instance
typedef struct tagPARSE_inst {
	FILE		  * pFile;      //!< configuration file to parse
	int16			strNumb;    //!< string number in configuration file
	tPARSE_cfg		cfg;        //!< parsed configuration
	tCHSIM_inst	  * pChsim;		//!< pointer to channel simulator instance
} tPARSE_inst;



/******************************************************************************
External functions
******************************************************************************/

//! Initialize Configuration parser object.
/*! This function parses command lines arguments 
	and opens configuration file.
  \param    this			pointer to Configuration parser instance
  \param	pChsim			pointer to channel simulator instance
  \param	argc			argument of main
  \param	argv			argument of main
*/
_extern_c_ void PARSE_init( tPARSE_inst * this, tCHSIM_inst		* pChsim,
							int			  argc, char			* argv[] );


//! Parse configuration file.
/*! This function reads and parses configuration file.
	Configuration file may consists from several session.
	Result is returned at each end of session.
    Return NULL if no more session available. 
  \param      this			pointer to Configuration parser instance
  \return					pointer to session configuration, NULL on end of file
*/
_extern_c_ tPARSE_cfg * PARSE_parseCfg( tPARSE_inst * this );


#endif //_PARSE_CFG_H_
